@@ -16,7 +16,9 @@ class CompileCommand(CommandBase):
                  sketch, build_cache_path=None, build_path=None, build_properties=None, fqbn=None, output_dir=None,
                  port=None, preprocess=None, show_properties=None, upload=None, verify=None, vid_pid=None,
                  warnings=None, libraries=None, library=None, optimize_for_debug=None, export_binaries=None,
-                 programmer=None, clean=None, only_compilation_database=None):
+                 programmer=None, clean=None, only_compilation_database=None, discovery_timeout=None, protocol=None,
+                 board_options=None, encrypt_key=None, keys_keychain=None, sign_key=None, dump_profile=None,
+                 profile=None):
         """
         Calls the :code:`compile` command
 
@@ -60,6 +62,22 @@ class CompileCommand(CommandBase):
         :type clean: bool or NoneType
         :param only_compilation_database: Just produce the compilation database, without actually compiling.
         :type only_compilation_database: bool or NoneType
+        :param discovery_timeout: Max time to wait for port discovery, e.g.: 30s, 1m (default 5s)
+        :type discovery_timeout: str or NoneType
+        :param protocol: Upload port protocol, e.g: serial
+        :type protocol: str or NoneType
+        :param board_options: Board options
+        :type board_options: dict or NoneType
+        :param encrypt_key: The name of the custom encryption key to use to encrypt a binary during the compile process. Used only by the platforms that support it.
+        :type encrypt_key: str or NoneType
+        :param keys_keychain: The path of the dir to search for the custom keys to sign and encrypt a binary. Used only by the platforms that support it.
+        :type keys_keychain: str or NoneType
+        :param sign_key: The name of the custom signing key to use to sign a binary during the compile process. Used only by the platforms that support it.
+        :type sign_key: str or NoneType
+        :param dump_profile: Create and print a profile configuration from the build.
+        :type dump_profile: bool or NoneType
+        :param profile: Sketch profile to use
+        :type profile: str or NoneType
         :return: The output of the related command
         :rtype: dict
         """
@@ -105,5 +123,23 @@ class CompileCommand(CommandBase):
             args.append(flags.CLEAN)
         if only_compilation_database is True:
             args.append(flags.ONLY_COMPILATION_DATABASE)
+        if discovery_timeout:
+            args.extend([flags.DISCOVERY_TIMEOUT, CommandBase._strip_arg(discovery_timeout)])
+        if protocol:
+            args.extend([flags.PROTOCOL, CommandBase._strip_arg(protocol)])
+        if board_options:
+            for option_name, option_value in board_options.items():
+                option = "%s=%s" % (CommandBase._strip_arg(option_name), CommandBase._strip_arg(option_value))
+                args.extend([flags.BOARD_OPTIONS, option])
+        if encrypt_key:
+            args.extend([flags.ENCRYPT_KEY, CommandBase._strip_arg(encrypt_key)])
+        if keys_keychain:
+            args.extend([flags.KEYS_KEYCHAIN, CommandBase._strip_arg(keys_keychain)])
+        if sign_key:
+            args.extend([flags.SIGN_KEY, CommandBase._strip_arg(sign_key)])
+        if dump_profile is True:
+            args.append(flags.DUMP_PROFILE)
+        if profile:
+            args.extend([flags.PROFILE, CommandBase._strip_arg(profile)])
         args.append(CommandBase._strip_arg(sketch))
         return self._exec(args)
